import { amountFromBaseUnits, parseAmount } from "@wormhole-foundation/sdk-base";
import { getTokenDetails } from "./token";
export class RouteTransferRequest {
    from;
    to;
    source;
    destination;
    fromChain;
    toChain;
    constructor(from, to, fromChain, toChain, source, destination) {
        this.from = from;
        this.fromChain = fromChain;
        this.to = to;
        this.toChain = toChain;
        this.source = source;
        this.destination = destination;
    }
    parseAmount(amt) {
        return parseAmount(amt, this.source.decimals);
    }
    amountFromBaseUnits(amt) {
        return amountFromBaseUnits(amt, this.source.decimals);
    }
    displayQuote(quote) {
        let dq = {
            sourceToken: {
                token: quote.sourceToken.token,
                amount: amountFromBaseUnits(quote.sourceToken.amount, this.source.decimals),
            },
            destinationToken: {
                token: quote.destinationToken.token,
                amount: amountFromBaseUnits(quote.destinationToken.amount, this.destination.decimals),
            },
        };
        if (quote.relayFee) {
            dq.relayFee = {
                token: quote.relayFee.token,
                amount: amountFromBaseUnits(quote.relayFee.amount, this.source.decimals),
            };
        }
        if (quote.destinationNativeGas) {
            dq.destinationNativeGas = amountFromBaseUnits(quote.destinationNativeGas, this.source.decimals);
        }
        return dq;
    }
    static async create(wh, params, fromChain, toChain) {
        fromChain = fromChain ?? wh.getChain(params.from.chain);
        toChain = toChain ?? wh.getChain(params.to.chain);
        const sourceDetails = await getTokenDetails(fromChain, params.source);
        const destDetails = await getTokenDetails(toChain, params.destination);
        const rtr = new RouteTransferRequest(params.from, params.to, fromChain, toChain, sourceDetails, destDetails);
        return rtr;
    }
}
//# sourceMappingURL=request.js.map